@@ -133,8 +133,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 				{
 					if((errno != EEXIST) && (errno != 0))
 					{
-						print_error("mkdir", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
+						print_error("mkdir", oparg->argv[loop_dst], __FILE__, __LINE__, cpdd);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -176,8 +175,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 
 		if(errno != 0)
 		{
-			print_error("realpath", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
+			print_error("realpath", oparg->argv[loop_dst], __FILE__, __LINE__, cpdd);
 			exit(EXIT_FAILURE);
 		}
 
@@ -185,8 +183,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 	}
 	else
 	{
-		print_error("realpath", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
+		print_error("realpath", oparg->argv[loop_dst], __FILE__, __LINE__, cpdd);
 		exit(EXIT_FAILURE);
 	}
 
@@ -229,8 +226,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 
 			if(errno != 0)
 			{
-				print_error("realpath", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, _("error : %s\n"), oparg->argv[loop]);
+				print_error("realpath", oparg->argv[loop], __FILE__, __LINE__, cpdd);
 				continue;
 			}
 		}
@@ -321,8 +317,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 				{
 					if((errno != EEXIST) && (errno != 0))
 					{
-						print_error("mkdir", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
+						print_error("mkdir", oparg->argv[loop_dst], __FILE__, __LINE__, cpdd);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -458,7 +453,15 @@ static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, con
 		this_dir = NULL;\
 	}\
 }
-#define DO_NOT_OVERWRITE { cpinfo->dst_para = SKIP; }
+#define DO_NOT_OVERWRITE \
+{\
+	cpinfo->dst_para = SKIP;\
+	struct stat stat_buf;\
+	if(stat(cpinfo->src, &stat_buf) == 0)\
+	{\
+		cpdd->total_source += stat_buf.st_size;\
+	}\
+}
 
 /*******************************************************************************
 *******************************************************************************/
@@ -739,8 +742,7 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 
 		if((errno != EEXIST) && (errno != 0))
 		{
-			print_error("mkdir", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
+			print_error("mkdir", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 	}
 	else
@@ -763,8 +765,7 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 
 	if(stat(cpinfo->src, stat_buf) != 0)
 	{
-		print_error("stat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), cpinfo->src);
+		print_error("stat", cpinfo->src, __FILE__, __LINE__, cpdd);
 		free(stat_buf);
 		stat_buf = NULL;
 	}
@@ -880,14 +881,12 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 
 		if(closedir(dp) == -1)
 		{
-			print_error("closedir", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, _("error : %s\n"), src_dir);
+			print_error("closedir", src_dir, __FILE__, __LINE__, cpdd);
 		}
 	}
 	else
 	{
-		print_error("opendir", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, _("error : %s\n"), src_dir);
+		print_error("opendir", src_dir, __FILE__, __LINE__, cpdd);
 	}
 
 	/* フォルダ削除用 */
