@@ -1,6 +1,7 @@
 #ifndef DO_COMPARE_VERIFY_ONE_H
 #define DO_COMPARE_VERIFY_ONE_H
 
+#include "gettext.h"
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
@@ -23,7 +24,7 @@ static inline void compare_verify_one(const OPArg *oparg, const SDir *sdir, CPIn
 		break;
 
 	default:
-		fprintf(stderr, "ハッシュチェックオプションが不正です\n");
+		fprintf(stderr, _("ハッシュチェックオプションが不正です\n"));
 		break;
 	}
 }
