@@ -1,10 +1,12 @@
 #define _GNU_SOURCE
 
+#include "gettext.h"
 #include "struct_SDir.h"
 #include "xmalloc.h"
 
 #include <errno.h>
 #include <fcntl.h>
+
 #include <glib.h>
 
 /* 関数プロトタイプ */
@@ -40,14 +42,14 @@ SDir * get_settings_dir(void)
 			errno = 0;
 			if((sdir->current_fd = open(".", O_RDONLY)) == -1)
 			{
-				printf("errno is %d\n", errno);
+				printf(_("errno is %d\n"), errno);
 				perror("get_settings_dir");
 				exit(EXIT_FAILURE);
 			}
 		}
 		else
 		{
-			printf("errno is %d\n", errno);
+			printf(_("errno is %d\n"), errno);
 			perror("get_settings_dir");
 			exit(EXIT_FAILURE);
 		}
