@@ -15,7 +15,7 @@ static void print_error(const char *func, const char *path, const char *source_c
 *******************************************************************************/
 static void print_error(const char *func, const char *path, const char *source_code_file_name, const int line, CPDD *cpdd)
 {
-	printf(_("%s : %d行\n"), source_code_file_name, line);
+	fprintf(stderr, _("%s : %d行\n"), source_code_file_name, line);
 
 	if(strcmp(func, "NULL") != 0)
 	{
