@@ -12,8 +12,7 @@
 		{\
 			if((errno != ENOTEMPTY) && (errno != ENOENT))\
 			{\
-				print_error("rmdir", __FILE__, __LINE__, cpdd);\
-				fprintf(stderr, _("error : %s\n"), cpinfo->src);\
+				print_error("rmdir", cpinfo->src, __FILE__, __LINE__, cpdd);\
 			}\
 		}\
 		else \
