@@ -12,8 +12,7 @@
 		{\
 			if(errno != ENOENT)\
 			{\
-				print_error("unlink", __FILE__, __LINE__, cpdd);\
-				fprintf(stderr, _("error : %s\n"), cpinfo->src);\
+				print_error("unlink", cpinfo->src, __FILE__, __LINE__, cpdd);\
 			}\
 		}\
 		else \
