@@ -5,6 +5,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include "gettext.h"
+
 #include <signal.h>
 #include <unistd.h>
 
@@ -36,13 +38,13 @@ void set_signal(void)
 void handler(int sig)
 {
 	fprintf(stderr, "\n");
-	fprintf(stderr, "ERROR!");
-	fprintf(stderr, "signal number = %d\n", sig);
+	fprintf(stderr, _("ERROR!"));
+	fprintf(stderr, _("signal number = %d\n"), sig);
 
 	if(write_now != NULL)
 	{
 		unlink(write_now);
-		fprintf(stderr, "remove : %s\n", write_now);
+		fprintf(stderr, _("remove : %s\n"), write_now);
 	}
 
 	exit(EXIT_FAILURE);
