@@ -27,10 +27,10 @@ static long psize;
 static md5_state_t state;
 static int read_size[BUF_NUM];
 static off_t total;
-static int r_number;
-static int a_number;
-static _Bool read_err;
-static _Bool read_finish;
+static int read_index;
+static int append_index;
+static _Bool is_read_err;
+static _Bool is_read_finish;
 
 /* 関数プロトタイプ */
 void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
@@ -47,8 +47,8 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	read_size[0] = 0;
 	read_size[1] = 0;
 	total = 0;
-	read_err = false;
-	read_finish = false;
+	is_read_err = false;
+	is_read_finish = false;
 
 	if(psize == 0)
 	{
@@ -96,10 +96,6 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	{
 		print_error("close", cpinfo->dst, __FILE__, __LINE__, cpdd);
 	}
-/*
-	free(buf[0]);
-	free(buf[1]);
-*/
 }
 
 /*******************************************************************************
@@ -138,29 +134,29 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 	{
 		md5_init(&state);
 
-		r_number = 0;
-		a_number = 1;
+		read_index = 0;
+		append_index = 1;
 		pthread_t t1;
 		pthread_t t2;
 
-		pthread_create(&t1, NULL, read_func, (void *)&r_number);
+		pthread_create(&t1, NULL, read_func, (void *)&read_index);
 		pthread_join(t1, NULL);
 
 		int swap;
 
 		for(;;)
 		{
-			swap = r_number;
-			r_number = a_number;
-			a_number = swap;
+			swap = read_index;
+			read_index = append_index;
+			append_index = swap;
 
-			pthread_create(&t1, NULL, read_func, (void *)&r_number);
-			pthread_create(&t2, NULL, append_func, (void *)&a_number);
+			pthread_create(&t1, NULL, read_func, (void *)&read_index);
+			pthread_create(&t2, NULL, append_func, (void *)&append_index);
 
 			pthread_join(t1, NULL);
 			pthread_join(t2, NULL);
 
-			if((read_finish == true) || (read_err == true))
+			if((is_read_finish == true) || (is_read_err == true))
 			{
 				break;
 			}
@@ -230,13 +226,25 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			}
 		}
 	}
+
+	if(buf[0] != NULL)
+	{
+		free(buf[0]);
+		buf[0] = NULL;
+	}
+
+	if(buf[1] != NULL)
+	{
+		free(buf[1]);
+		buf[1] = NULL;
+	}
 }
 
 /*******************************************************************************
 *******************************************************************************/
 static void * read_func(void *dummy)
 {
-	int i = r_number;
+	int i = read_index;
 
 	/* 
 	 * O_DIRECTを使用するとアライメントの調整などが面倒なので、
@@ -246,11 +254,11 @@ static void * read_func(void *dummy)
 
 	if(read_size[i] == 0)
 	{
-		read_finish = true;
+		is_read_finish = true;
 	}
 	else if(read_size[i] < 0)
 	{
-		read_err = true;
+		is_read_err = true;
 	}
 	else
 	{
@@ -265,7 +273,7 @@ static void * read_func(void *dummy)
 *******************************************************************************/
 static void * append_func(void *dummy)
 {
-	int i = a_number;
+	int i = append_index;
 
 	md5_append(&state, buf[i], read_size[i]);
 
