@@ -125,7 +125,7 @@ static void write_log_hash_check(const CPInfo *cpinfo, const OPArg *oparg, const
 
 		if(check == false)
 		{
-			print_error("fputs", __FILE__, __LINE__, cpdd);
+			print_error("fputs", "NULL", __FILE__, __LINE__, cpdd);
 			fprintf(stderr, _("コンペアログの保存に失敗しました\n"));
 		}
 		else
@@ -135,12 +135,12 @@ static void write_log_hash_check(const CPInfo *cpinfo, const OPArg *oparg, const
 
 		if(fclose(log) == EOF)
 		{
-			print_error("fclose", __FILE__, __LINE__, cpdd);
+			print_error("fclose", "NULL", __FILE__, __LINE__, cpdd);
 		}
 	}
 	else
 	{
-		print_error("fopen", __FILE__, __LINE__, cpdd);
+		print_error("fopen", "NULL", __FILE__, __LINE__, cpdd);
 		fprintf(stderr, _("コンペアログの保存に失敗しました\n"));
 	}
 }
